<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

add_action( 'init', 'apushome_process_change_profile_form', 9999 );
function apushome_process_change_profile_form() {
    if ( ! isset( $_POST['change_profile_form'] ) ) {
        return;
    }
    $user = wp_get_current_user();

    $user_avatar = isset($_POST['user_avatar']) ?  sanitize_user( $_POST['user_avatar'] ) : '';
    update_user_meta( $user->ID, 'apus_avatar', $user_avatar );
    
}

function apushome_user_profile_fields( $user ) {
    wp_enqueue_media();
    wp_enqueue_script( 'apushome-upload', get_template_directory_uri() . '/js/upload.js', array( 'jquery' ), '20150330', true );

    $avatar = get_the_author_meta( 'apus_avatar', $user->ID );
    $avatar_url = wp_get_attachment_image_src($avatar, 'full');

    ?>
    <h3><?php esc_html_e( 'User Profile', 'apushome' ); ?></h3>

    <table class="form-table">
        <tbody>
            <tr>
                <th>
                    <label for="lecturer_job"><?php esc_html_e( 'Avatar', 'apushome' ); ?></label>
                </th>
                <td>
                    <div class="screenshot avatar-screenshot">
                        <?php if ( !empty($avatar_url[0]) ) { ?>
                            <img src="<?php echo esc_url($avatar_url[0]); ?>" alt="" style="max-width:100%;"/>
                        <?php } ?>
                    </div>
                    <input class="widefat upload_image" name="user_avatar" type="hidden" value="<?php echo esc_attr($avatar); ?>" />
                    <div class="upload_image_action">
                        <input type="button" class="button btn btn-theme add-image" value="<?php echo esc_html__( 'Add Avatar', 'apushome' ); ?>">
                        <input type="button" class="button btn btn-theme-second remove-image" value="<?php echo esc_html__( 'Remove Avatar', 'apushome' ); ?>">
                    </div>
                </td>
            </tr>
        </tbody>
    </table>
    <?php
}
add_action( 'show_user_profile', 'apushome_user_profile_fields' );
add_action( 'edit_user_profile', 'apushome_user_profile_fields' );

function apushome_save_user_profile_fields( $user_id ) {
    if ( !current_user_can( 'edit_user', $user_id ) ) {
        return false;
    }

    $user_avatar = isset($_POST['user_avatar']) ?  sanitize_user( $_POST['user_avatar'] ) : '';
    update_user_meta( $user_id, 'apus_avatar', $user_avatar );
}

add_action( 'personal_options_update', 'apushome_save_user_profile_fields' );
add_action( 'edit_user_profile_update', 'apushome_save_user_profile_fields' );


add_filter('get_avatar', 'apushome_get_avatar_filter', 10, 100);

function apushome_get_avatar_filter($avatar, $id_or_email="", $size="", $default="", $alt="") {
    if (is_object($id_or_email)) {
        
        $avatar_id = get_the_author_meta( 'apus_avatar', $id_or_email->ID );
        if ( !empty($avatar_id) ) {
            $avatar_url = wp_get_attachment_image_src($avatar_id, 'full');
            if ( !empty($avatar_url[0]) ) {
                $avatar = '<img src="'.$avatar_url[0].'" width="'.$size.'" height="'.$size.'" alt="'.$alt.'" class="avatar avatar-'.$size.' wp-user-avatar wp-user-avatar-'.$size.' photo avatar-default" />';
            }
        }
    } else {
        $avatar_id = get_the_author_meta( 'apus_avatar', $id_or_email );
        if ( !empty($avatar_id) ) {
            $avatar_url = wp_get_attachment_image_src($avatar_id, 'full');
            if ( !empty($avatar_url[0]) ) {
                $avatar = '<img src="'.$avatar_url[0].'" width="'.$size.'" height="'.$size.'" alt="'.$alt.'" class="avatar avatar-'.$size.' wp-user-avatar wp-user-avatar-'.$size.' photo avatar-default" />';
            }
        }
    }
    return $avatar;
}


add_action( 'wp_ajax_apushome_process_register', 'apushome_process_register_form' );
add_action( 'wp_ajax_nopriv_apushome_process_register', 'apushome_process_register_form' );

function apushome_process_register_form() {
    
    if ( ! get_option( 'users_can_register' ) ) {
        $return = array( 'class' => 'danger', 'msg' => __( 'Registrations are not allowed.', 'realia' ) );
        echo json_encode($return);
        die();
    }

    if ( empty( $_REQUEST['name'] ) || empty( $_REQUEST['email'] ) ) {
        $return = array( 'class' => 'danger', 'msg' => __( 'Username and e-mail are required.', 'realia' ) );
        echo json_encode($return);
        die();
    }

    $name = sanitize_user( $_REQUEST['name'] );
    $email = sanitize_email( $_REQUEST['email'] );
    $password = sanitize_text_field( $_REQUEST['password'] );
    $first_name = sanitize_text_field( $_REQUEST['first_name'] );
    $last_name = sanitize_text_field( $_REQUEST['last_name'] );
    $phone = sanitize_text_field( $_REQUEST['phone'] );

    $user_id = username_exists( $name );

    if ( ! empty( $user_id ) ) {
        $return = array( 'class' => 'danger', 'msg' => __( 'User already exists.', 'realia' ) );
        echo json_encode($return);
        die();
    }

    if ( $_REQUEST['password'] != $_REQUEST['password_retype'] ) {
        $return = array( 'class' => 'danger', 'msg' => __( 'Passwords must be same.', 'realia' ) );
        echo json_encode($return);
        die();
    }

    $terms_id = get_theme_mod( 'realia_submission_terms', false );

    if ( $terms_id && empty( $_REQUEST['agree_terms'] ) ) {
        $return = array( 'class' => 'danger', 'msg' => __( 'You must agree terms &amp; conditions.', 'realia' ) );
        echo json_encode($return);
        die();
    }

    if ( $_REQUEST['password'] != $_REQUEST['password_retype'] ) {
        $return = array( 'class' => 'danger', 'msg' => __( 'Passwords must be same.', 'realia' ) );
        echo json_encode($return);
        die();
    }

    $user = wp_create_user( $name, $password, $email );

    if ( is_wp_error( $user ) ) {
        $return = array( 'class' => 'danger', 'msg' => $user->get_error_message() );
        echo json_encode($return);
        die();
    }

    // 'admin' / 'both'
    wp_new_user_notification( $user, null, 'both' );

    update_user_meta( $user, 'last_name', $last_name );
    update_user_meta( $user, 'first_name', $first_name );
    update_user_meta( $user, 'phone', $phone );


    $return = array( 'class' => 'success', 'msg' => __( 'You have been successfully registered.', 'realia' ) );
    echo json_encode($return);
    die();
}

add_action( 'wp_ajax_apushome_process_login', 'apushome_process_login_form' );
add_action( 'wp_ajax_nopriv_apushome_process_login', 'apushome_process_login_form' );

function apushome_process_login_form() {

    if ( empty( $_REQUEST['login'] ) || empty( $_REQUEST['password'] ) ) {
        $return = array( 'class' => 'danger', 'msg' => __( 'Login and password are required.', 'realia' ) );
        echo json_encode($return);
        die();
    }

    $login = sanitize_text_field( $_REQUEST['login'] );
    $password = sanitize_text_field( $_REQUEST['password'] );

    $user = wp_signon( array(
        'user_login'        => $login,
        'user_password'     => $password,
    ), false );

    if ( is_wp_error( $user ) ) {
        $return = array( 'class' => 'danger', 'msg' => $user->get_error_message() );
        echo json_encode($return);
        die();
    }

    $return = array( 'class' => 'success', 'msg' => __( 'You have been successfully logged.', 'realia' ) );
    echo json_encode($return);
    die();
}