<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!class_exists('Apushome_Redux_Framework_Config')) {

    class Apushome_Redux_Framework_Config
    {
        public $args = array();
        public $sections = array();
        public $theme;
        public $ReduxFramework;

        public function __construct()
        {
            if (!class_exists('ReduxFramework')) {
                return;
            }
            add_action('init', array($this, 'initSettings'), 10);
        }

        public function initSettings()
        {
            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        public function setSections()
        {
            global $wp_registered_sidebars;
            $sidebars = array();

            if ( !empty($wp_registered_sidebars) ) {
                foreach ($wp_registered_sidebars as $sidebar) {
                    $sidebars[$sidebar['id']] = $sidebar['name'];
                }
            }
            $columns = array( '1' => esc_html__('1 Column', 'apushome'),
                '2' => esc_html__('2 Columns', 'apushome'),
                '3' => esc_html__('3 Columns', 'apushome'),
                '4' => esc_html__('4 Columns', 'apushome'),
                '6' => esc_html__('6 Columns', 'apushome')
            );
            
            $general_fields = array();
            if ( !function_exists( 'wp_site_icon' ) ) {
                $general_fields[] = array(
                    'id' => 'media-favicon',
                    'type' => 'media',
                    'title' => esc_html__('Favicon Upload', 'apushome'),
                    'subtitle' => esc_html__('Upload a 16px x 16px .png or .gif image that will be your favicon.', 'apushome'),
                );
            }
            $general_fields[] = array(
                'id' => 'preload',
                'type' => 'switch',
                'title' => esc_html__('Preload Website', 'apushome'),
                'default' => true,
            );
            $general_fields[] = array(
                'id' => 'image_lazy_loading',
                'type' => 'switch',
                'title' => esc_html__('Image Lazy Loading', 'apushome'),
                'default' => true,
            );
            // General Settings Tab
            $this->sections[] = array(
                'icon' => 'el-icon-cogs',
                'title' => esc_html__('General', 'apushome'),
                'fields' => $general_fields
            );
            
            // Header
            $this->sections[] = array(
                'icon' => 'el el-website',
                'title' => esc_html__('Header', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'media-logo',
                        'type' => 'media',
                        'title' => esc_html__('Logo Upload', 'apushome'),
                        'subtitle' => esc_html__('Upload a .png or .gif image that will be your logo.', 'apushome'),
                    ),
                    array(
                        'id' => 'media-mobile-logo',
                        'type' => 'media',
                        'title' => esc_html__('Mobile Logo Upload', 'apushome'),
                        'subtitle' => esc_html__('Upload a .png or .gif image that will be your logo.', 'apushome'),
                    ),
                    array(
                        'id' => 'header_type',
                        'type' => 'select',
                        'title' => esc_html__('Header Layout Type', 'apushome'),
                        'subtitle' => esc_html__('Choose a header for your website.', 'apushome'),
                        'options' => apushome_get_header_layouts()
                    ),
                    array(
                        'id' => 'keep_header',
                        'type' => 'switch',
                        'title' => esc_html__('Keep Header', 'apushome'),
                        'default' => false
                    ),
                    array(
                        'id' => 'show_create_property_btn',
                        'type' => 'switch',
                        'title' => esc_html__('Show Create Property Button', 'apushome'),
                        'default' => true
                    ),
                    array(
                        'id' => 'show_login_register',
                        'type' => 'switch',
                        'title' => esc_html__('Show Login/Register/Profile', 'apushome'),
                        'default' => true
                    ),
                )
            );
            // Footer
            $this->sections[] = array(
                'icon' => 'el el-website',
                'title' => esc_html__('Footer', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'footer_type',
                        'type' => 'select',
                        'title' => esc_html__('Footer Layout Type', 'apushome'),
                        'subtitle' => esc_html__('Choose a footer for your website.', 'apushome'),
                        'options' => apushome_get_footer_layouts()
                    ),
                    array(
                        'id' => 'copyright_text',
                        'type' => 'editor',
                        'title' => esc_html__('Copyright Text', 'apushome'),
                        'default' => 'Powered by Redux Framework.',
                        'required' => array('footer_type','=','')
                    ),
                    array (
                        'title' => esc_html__('Logo Copyright For Footer Default', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('Logo Copyright of the site.', 'apushome').'</em>',
                        'id' => 'logo_copyright',
                        'type' => 'media',
                    ),
                    array(
                        'id' => 'back_to_top',
                        'type' => 'switch',
                        'title' => esc_html__('Back To Top Button', 'apushome'),
                        'subtitle' => esc_html__('Toggle whether or not to enable a back to top button on your pages.', 'apushome'),
                        'default' => true,
                    ),
                )
            );

            // Blog settings
            $this->sections[] = array(
                'icon' => 'el el-pencil',
                'title' => esc_html__('Blog', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'show_blog_breadcrumbs',
                        'type' => 'switch',
                        'title' => esc_html__('Breadcrumbs', 'apushome'),
                        'default' => 1
                    ),
                    array (
                        'title' => esc_html__('Breadcrumbs Background Color', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('The breadcrumbs background color of the site.', 'apushome').'</em>',
                        'id' => 'blog_breadcrumb_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id' => 'blog_breadcrumb_image',
                        'type' => 'media',
                        'title' => esc_html__('Breadcrumbs Background', 'apushome'),
                        'subtitle' => esc_html__('Upload a .jpg or .png image that will be your breadcrumbs.', 'apushome'),
                    ),
                )
            );
            // Archive Blogs settings
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Blog & Post Archives', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'blog_archive_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Layout', 'apushome'),
                        'subtitle' => esc_html__('Select the variation you want to apply on your store.', 'apushome'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Only', 'apushome'),
                                'alt' => esc_html__('Main Only', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'alt' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'alt' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'blog_archive_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apushome'),
                        'default' => false
                    ),
                    array(
                        'id' => 'blog_archive_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Left Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'blog_archive_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Right Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apushome'),
                        'options' => $sidebars
                        
                    ),
                    array(
                        'id' => 'blog_display_mode',
                        'type' => 'select',
                        'title' => esc_html__('Display Mode', 'apushome'),
                        'options' => array(
                            'grid' => esc_html__('Grid Layout', 'apushome'),
                            'grid-v2' => esc_html__('Grid Version 2 Layout', 'apushome'),
                            'mansory' => esc_html__('Mansory Layout', 'apushome'),
                            'list' => esc_html__('List Layout', 'apushome')
                        ),
                        'default' => 'grid'
                    ),
                    array(
                        'id' => 'blog_columns',
                        'type' => 'select',
                        'title' => esc_html__('Blog Columns', 'apushome'),
                        'options' => $columns,
                        'default' => 1
                    ),
                    array(
                        'id' => 'blog_item_thumbsize',
                        'type' => 'text',
                        'title' => esc_html__('Thumbnail Size', 'apushome'),
                        'subtitle' => esc_html__('This featured for the site is using Visual Composer.', 'apushome'),
                        'desc' => esc_html__('Enter thumbnail size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height) .', 'apushome'),
                    ),

                )
            );
            // Single Blogs settings
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Blog', 'apushome'),
                'fields' => array(
                    
                    array(
                        'id' => 'blog_single_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Archive Blog Layout', 'apushome'),
                        'subtitle' => esc_html__('Select the variation you want to apply on your store.', 'apushome'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Only', 'apushome'),
                                'alt' => esc_html__('Main Only', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'alt' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'alt' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'blog_single_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apushome'),
                        'default' => false
                    ),
                    array(
                        'id' => 'blog_single_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Single Blog Left Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'blog_single_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Single Blog Right Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'show_blog_social_share',
                        'type' => 'switch',
                        'title' => esc_html__('Show Social Share', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'show_blog_releated',
                        'type' => 'switch',
                        'title' => esc_html__('Show Releated Posts', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'number_blog_releated',
                        'type' => 'text',
                        'title' => esc_html__('Number of related posts to show', 'apushome'),
                        'required' => array('show_blog_releated', '=', '1'),
                        'default' => 3,
                        'min' => '1',
                        'step' => '1',
                        'max' => '20',
                        'type' => 'slider'
                    ),
                    array(
                        'id' => 'releated_blog_columns',
                        'type' => 'select',
                        'title' => esc_html__('Releated Blogs Columns', 'apushome'),
                        'required' => array('show_blog_releated', '=', '1'),
                        'options' => $columns,
                        'default' => 3
                    ),

                )
            );
            // Agency
            $this->sections[] = array(
                'title' => esc_html__('Agency', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'show_agency_breadcrumbs',
                        'type' => 'switch',
                        'title' => esc_html__('Breadcrumbs', 'apushome'),
                        'default' => 1
                    ),
                    array (
                        'title' => esc_html__('Breadcrumbs Background Color', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('The breadcrumbs background color of the site.', 'apushome').'</em>',
                        'id' => 'agency_breadcrumb_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id' => 'agency_breadcrumb_image',
                        'type' => 'media',
                        'title' => esc_html__('Breadcrumbs Background', 'apushome'),
                        'subtitle' => esc_html__('Upload a .jpg or .png image that will be your breadcrumbs.', 'apushome'),
                    )
                )
            );
            // Archive settings
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Agency Archives', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'agency_archive_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Sidebar position', 'apushome'),
                        'subtitle' => esc_html__('Select the layout you want to apply on your archive agency page.', 'apushome'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Content', 'apushome'),
                                'alt' => esc_html__('Main Content', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left Sidebar - Main Content', 'apushome'),
                                'alt' => esc_html__('Left Sidebar - Main Content', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main Content - Right Sidebar', 'apushome'),
                                'alt' => esc_html__('Main Content - Right Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'agency_archive_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apushome'),
                        'default' => false
                    ),
                    array(
                        'id' => 'agency_archive_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Left Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'agency_archive_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Right Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'agency_columns',
                        'type' => 'select',
                        'title' => esc_html__('Agency Columns', 'apushome'),
                        'options' => $columns,
                        'default' => 4
                    ),
                    
                )
            );
            // Agency Page
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Single Agency', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'agency_single_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Sidebar position', 'apushome'),
                        'subtitle' => esc_html__('Select the layout you want to apply on your Single Product Page.', 'apushome'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Only', 'apushome'),
                                'alt' => esc_html__('Main Only', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'alt' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'alt' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'agency_single_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apushome'),
                        'default' => false
                    ),
                    array(
                        'id' => 'agency_single_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Single Product Left Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'agency_single_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Single Product Right Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'show_agency_social_share',
                        'type' => 'switch',
                        'title' => esc_html__('Show Social Share', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'show_agency_agents',
                        'type' => 'switch',
                        'title' => esc_html__('Show Agency Agents', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'number_agency_agents',
                        'title' => esc_html__('Number agents', 'apushome'),
                        'default' => 4,
                        'min' => '1',
                        'step' => '1',
                        'max' => '20',
                        'type' => 'slider',
                        'required' => array('show_agency_agents','equals',true),
                    ),
                    array(
                        'id' => 'agent_agency_columns',
                        'type' => 'select',
                        'title' => esc_html__('Columns', 'apushome'),
                        'options' => $columns,
                        'default' => 4,
                        'required' => array('show_agency_agents','equals',true),
                    ),

                )
            );
            // Agent
            $this->sections[] = array(
                'title' => esc_html__('Agent', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'show_agent_breadcrumbs',
                        'type' => 'switch',
                        'title' => esc_html__('Breadcrumbs', 'apushome'),
                        'default' => 1
                    ),
                    array (
                        'title' => esc_html__('Breadcrumbs Background Color', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('The breadcrumbs background color of the site.', 'apushome').'</em>',
                        'id' => 'agent_breadcrumb_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id' => 'agent_breadcrumb_image',
                        'type' => 'media',
                        'title' => esc_html__('Breadcrumbs Background', 'apushome'),
                        'subtitle' => esc_html__('Upload a .jpg or .png image that will be your breadcrumbs.', 'apushome'),
                    )
                )
            );
            // Archive settings
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Agent Archives', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'agent_archive_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Sidebar position', 'apushome'),
                        'subtitle' => esc_html__('Select the layout you want to apply on your archive agent page.', 'apushome'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Content', 'apushome'),
                                'alt' => esc_html__('Main Content', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left Sidebar - Main Content', 'apushome'),
                                'alt' => esc_html__('Left Sidebar - Main Content', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main Content - Right Sidebar', 'apushome'),
                                'alt' => esc_html__('Main Content - Right Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'agent_archive_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apushome'),
                        'default' => false
                    ),
                    array(
                        'id' => 'agent_archive_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Left Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'agent_archive_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Right Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'agent_columns',
                        'type' => 'select',
                        'title' => esc_html__('Agent Columns', 'apushome'),
                        'options' => $columns,
                        'default' => 4
                    ),
                )
            );
            // Agent Page
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Single Agent', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'agent_single_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Sidebar position', 'apushome'),
                        'subtitle' => esc_html__('Select the layout you want to apply on your Single Product Page.', 'apushome'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Only', 'apushome'),
                                'alt' => esc_html__('Main Only', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'alt' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'alt' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'agent_single_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apushome'),
                        'default' => false
                    ),
                    array(
                        'id' => 'agent_single_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Single Product Left Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'agent_single_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Single Product Right Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'show_agent_properties',
                        'type' => 'switch',
                        'title' => esc_html__('Show Agent Properties', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'number_agent_properties',
                        'title' => esc_html__('Number properties', 'apushome'),
                        'default' => 4,
                        'min' => '1',
                        'step' => '1',
                        'max' => '20',
                        'type' => 'slider',
                        'required' => array('show_agent_properties','equals',true),
                    ),
                    array(
                        'id' => 'property_agent_columns',
                        'type' => 'select',
                        'title' => esc_html__('Columns', 'apushome'),
                        'options' => $columns,
                        'default' => 4,
                        'required' => array('show_agent_properties','equals',true),
                    ),
                    array(
                        'id' => 'show_agent_contact_form',
                        'type' => 'switch',
                        'title' => esc_html__('Show Agent Contact Form', 'apushome'),
                        'default' => 1
                    ),
                )
            );
            // Property Global Settings
            $pages = array();
            if ( is_admin() ) {
                $args = array(
                    'sort_order' => 'asc',
                    'sort_column' => 'post_title',
                    'number' => '',
                    'post_type' => 'page',
                    'post_status' => 'publish'
                ); 
                $allpages = get_pages($args);
                if ( !empty($allpages) ) {
                    foreach ($allpages as $page) {
                        $pages[$page->post_name] = $page->post_title;
                    }
                }
            }
            $this->sections[] = array(
                'title' => esc_html__('Property Global Setting', 'apushome'),
                'fields' => array(
                    array (
                        'id' => 'property_global_settings_favorite',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Favorite Settings', 'apushome').'</h3>',
                    ),
                    array(
                        'id' => 'enable_property_favorite',
                        'type' => 'switch',
                        'title' => esc_html__('Enable Property Favorite?', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'property_favorite_page_slug',
                        'type' => 'select',
                        'title' => esc_html__('Favorite Page', 'apushome'),
                        'options' => $pages,
                        'required' => array('enable_property_favorite', 'equals', 1),
                    ),
                    array (
                        'id' => 'property_global_settings_save_search',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Save Search Settings', 'apushome').'</h3>',
                    ),
                    array(
                        'id' => 'enable_property_save_search',
                        'type' => 'switch',
                        'title' => esc_html__('Enable Property Save Search?', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'save_search_title',
                        'type' => 'text',
                        'title' => esc_html__('Form Title', 'apushome'),
                        'default' => 'Save Search',
                        'required' => array('enable_property_save_search', 'equals', 1),
                    ),
                    array(
                        'id' => 'save_search_description',
                        'type' => 'textarea',
                        'title' => esc_html__('Form Description', 'apushome'),
                        'default' => '',
                        'required' => array('enable_property_save_search', 'equals', 1),
                    ),
                )
            );
            // Property Archive settings
            $this->sections[] = array(
                'title' => esc_html__('Property Archives Page', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'property_archive_layout_version',
                        'type' => 'select',
                        'title' => esc_html__('Archive Layout', 'apushome'),
                        'subtitle' => esc_html__('Choose a layout for archvie, taxonomy page.', 'apushome'),
                        'options' => array(
                            'default' => esc_html__('Default', 'apushome'),
                            'half-map' => esc_html__('Half Map', 'apushome'),
                            'full-map' => esc_html__('Full Map', 'apushome'),
                        ),
                        'default' => 'default'
                    ),
                    array(
                        'id' => 'property_archive_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Sidebar position', 'apushome'),
                        'subtitle' => esc_html__('Select the layout you want to apply on your archive property page.', 'apushome'),
                        'required' => array('property_archive_layout_version', 'equals', array('default', 'full-map')),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Content', 'apushome'),
                                'alt' => esc_html__('Main Content', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left Sidebar - Main Content', 'apushome'),
                                'alt' => esc_html__('Left Sidebar - Main Content', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main Content - Right Sidebar', 'apushome'),
                                'alt' => esc_html__('Main Content - Right Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'property_archive_fullwidth',
                        'type' => 'switch',
                        'title' => esc_html__('Is Full Width?', 'apushome'),
                        'default' => false,
                        'required' => array('property_archive_layout_version', 'equals', array('default', 'full-map')),
                    ),
                    array(
                        'id' => 'property_archive_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Left Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apushome'),
                        'options' => $sidebars,
                        'required' => array('property_archive_layout_version', 'equals', array('default', 'full-map')),
                    ),
                    array(
                        'id' => 'property_archive_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Right Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apushome'),
                        'options' => $sidebars,
                        'required' => array('property_archive_layout_version', 'equals', array('default', 'full-map')),
                    ),
                    array(
                        'id' => 'number_property_per_page',
                        'type' => 'text',
                        'title' => esc_html__('Number of Products Per Page', 'apushome'),
                        'default' => 12,
                        'min' => '1',
                        'step' => '1',
                        'max' => '100',
                        'type' => 'slider'
                    ),
                    array(
                        'id' => 'property_columns',
                        'type' => 'select',
                        'title' => esc_html__('Property Columns', 'apushome'),
                        'options' => $columns,
                        'default' => 3
                    ),
                    array(
                        'id' => 'property_pagination',
                        'type' => 'select',
                        'title' => esc_html__('Pagination Type', 'apushome'),
                        'options' => array(
                            'default' => esc_html__('Default', 'apushome'),
                            'loadmore' => esc_html__('Load More Button', 'apushome'),
                            'infinite' => esc_html__('Infinite Scrolling', 'apushome'),
                        ),
                        'default' => 'default'
                    ),
                )
            );
            // Single Property Page
            $yelp_cates = array();
            if ( is_admin() && function_exists('apushome_get_yelp_categories') ) {
                $yelp_cates = apushome_get_yelp_categories();
            }
            $options = array();
            if ( function_exists('apushome_get_default_places') ) {
                $options = apushome_get_default_places();
            }
            $this->sections[] = array(
                'title' => esc_html__('Property Detail page', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'property_single_layout_type',
                        'type' => 'select',
                        'title' => esc_html__('Property Layout Type', 'apushome'),
                        'options' => array(
                            'layout1' => esc_html__('Layout 1', 'apushome'),
                            'layout2' => esc_html__('Layout 2', 'apushome'),
                            'layout3' => esc_html__('Layout 3', 'apushome'),
                            'layout4' => esc_html__('Layout 4', 'apushome')
                        ),
                        'default' => 'layout1',
                    ),
                    array(
                        'id' => 'property_header_active_tab',
                        'type' => 'select',
                        'title' => esc_html__('Header active tab', 'apushome'),
                        'options' => array(
                            'gallery' => esc_html__('Gallery', 'apushome'),
                            'map' => esc_html__('Map', 'apushome'),
                            'mapview' => esc_html__('Map View', 'apushome'),
                        ),
                        'default' => 'gallery',
                        'required' => array('property_single_layout_type', '=', array('layout1', 'layout2'))
                    ),
                    array(
                        'id' => 'property_single_content_layout',
                        'type' => 'select',
                        'title' => esc_html__('Property Content Layout', 'apushome'),
                        'options' => array(
                            'default' => esc_html__('Default', 'apushome'),
                            'tabs' => esc_html__('Tabs', 'apushome')
                        ),
                        'default' => 'default',
                    ),
                    array(
                        'id'        => 'property_sort_content',
                        'type'      => 'sorter',
                        'title'     => esc_html__( 'Property Content', 'apushome' ),
                        'subtitle'  => esc_html__( 'Please drag and arrange the block', 'apushome' ),
                        'options'   => array(
                            'enabled' => array(
                                'description'            => esc_html__( 'Description', 'apushome' ),
                                'detail'       => esc_html__( 'Detail', 'apushome' ),
                                'amenities' => esc_html__( 'Amenities', 'apushome' ),
                                'nearby_yelp' => esc_html__( 'Nearby Yelp', 'apushome' ),
                                'walk_score' => esc_html__( 'Walk Score', 'apushome' ),
                                'virtual_tour' => esc_html__( 'Virtual Tour', 'apushome' ),
                                'floor' => esc_html__( 'Floor Plans', 'apushome' ),
                                'video' => esc_html__( 'Video', 'apushome' ),
                                'facilities' => esc_html__( 'Facilities', 'apushome' ),
                                'valuation' => esc_html__( 'Valuation', 'apushome' ),
                                'agents' => esc_html__( 'Agents', 'apushome' ),
                            ),
                            'disabled' => array()
                        ),
                        'required' => array('property_single_layout_type', '=', array('layout1', 'layout2'))
                    ),
                    array(
                        'id'        => 'property_sort_content_v2',
                        'type'      => 'sorter',
                        'title'     => esc_html__( 'Property Content', 'apushome' ),
                        'subtitle'  => esc_html__( 'Please drag and arrange the block', 'apushome' ),
                        'options'   => array(
                            'enabled' => array(
                                'description'            => esc_html__( 'Description', 'apushome' ),
                                'detail'       => esc_html__( 'Detail', 'apushome' ),
                                'amenities' => esc_html__( 'Amenities', 'apushome' ),
                                'map-tabs' => esc_html__( 'Google Map', 'apushome' ),
                                'nearby_yelp' => esc_html__( 'Nearby Yelp', 'apushome' ),
                                'walk_score' => esc_html__( 'Walk Score', 'apushome' ),
                                'virtual_tour' => esc_html__( 'Virtual Tour', 'apushome' ),
                                'floor' => esc_html__( 'Floor Plans', 'apushome' ),
                                'video' => esc_html__( 'Video', 'apushome' ),
                                'facilities' => esc_html__( 'Facilities', 'apushome' ),
                                'valuation' => esc_html__( 'Valuation', 'apushome' ),
                                'agents' => esc_html__( 'Agents', 'apushome' ),
                            ),
                            'disabled' => array()
                        ),
                        'required' => array('property_single_layout_type', '=', array('layout3', 'layout4'))
                    ),
                    array(
                        'id' => 'show_property_sub',
                        'type' => 'switch',
                        'title' => esc_html__('Show Sub Properties', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'show_property_similar',
                        'type' => 'switch',
                        'title' => esc_html__('Show Properties Similar', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'show_property_social',
                        'type' => 'switch',
                        'title' => esc_html__('Show Property Social', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'enable_sticky_sidebar',
                        'type' => 'switch',
                        'title' => esc_html__('Enable Sticky Sidebar', 'apushome'),
                        'default' => 1
                    ),
                    array (
                        'id' => 'api_settings_nearby_place',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Nearby Place Settings', 'apushome').'</h3>',
                    ),
                    array(
                        'id'         => 'property_nearby_place',
                        'type'       => 'repeater',
                        'title'      => esc_html__( 'Property Nearby Place', 'apushome' ),
                        'fields'     => array(
                            array(
                                'id' => 'nearby_place_title',
                                'type' => 'text',
                                'title' => esc_html__('Title', 'apushome'),
                            ),
                            array(
                                'id' => 'nearby_place_icon_font',
                                'type' => 'text',
                                'title' => esc_html__('Font Icon', 'apushome'),
                            ),
                            array(
                                'id' => 'nearby_place_image_icon',
                                'type' => 'media',
                                'title' => esc_html__('Image Icon', 'apushome'),
                                'subtitle' => esc_html__('Upload a .jpg or .png image for icon.', 'apushome')
                            ),
                            array(
                                'id' => 'nearby_place_category',
                                'type' => 'select',
                                'title' => esc_html__('Yelp Categories', 'apushome'),
                                'options' => $options,
                            ),
                            array(
                                'id' => 'nearby_place_marker',
                                'type' => 'media',
                                'title' => esc_html__('Marker Icon', 'apushome'),
                                'subtitle' => esc_html__('Upload a .jpg or .png image for icon.', 'apushome')
                            ),
                        )
                    ),
                    array (
                        'id' => 'api_settings_yelp',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Yelp Settings', 'apushome').'</h3>',
                    ),
                    array(
                        'id' => 'api_settings_yelp_id',
                        'type' => 'text',
                        'title' => esc_html__('Yelp App ID', 'apushome'),
                        'subtitle' => esc_html__('Add Yelp application ID. To get your Yelp Application ID, go to your Yelp Account.', 'apushome')
                    ),
                    array(
                        'id' => 'api_settings_yelp_app_secret',
                        'type' => 'text',
                        'title' => esc_html__('Yelp App Secret', 'apushome'),
                        'subtitle' => esc_html__('Put your Yelp App Secret here. You can find it in your Yelp Application Dashboard.', 'apushome')
                    ),
                    array(
                        'id' => 'api_settings_yelp_access_token',
                        'type' => 'text',
                        'title' => esc_html__('Yelp Access Token', 'apushome'),
                        'subtitle' => esc_html__('Click on the button bellow to get access token.', 'apushome'),
                        'description' => '<a href="#get_token" class="apus-get-token-btn button">'.esc_html__('Get Access Token', 'apushome').'</a>'
                    ),
                    array(
                        'id'         => 'api_settings_yelp_categories',
                        'type'       => 'repeater',
                        'title'      => esc_html__( 'Yelp Categories', 'apushome' ),
                        'fields'     => array(
                            array(
                                'id' => 'yelp_title',
                                'type' => 'text',
                                'title' => esc_html__('Title', 'apushome'),
                            ),
                            array(
                                'id' => 'yelp_category',
                                'type' => 'select',
                                'title' => esc_html__('Yelp Categories', 'apushome'),
                                'options' => $yelp_cates,
                            ),
                            array(
                                'id' => 'yelp_icon',
                                'type' => 'media',
                                'title' => esc_html__('Category Icon', 'apushome'),
                                'subtitle' => esc_html__('Upload a .jpg or .png image for icon.', 'apushome')
                            )
                        )
                    ),
                    array (
                        'id' => 'api_settings_walk_score',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Walk Score Settings', 'apushome').'</h3>',
                    ),
                    array(
                        'id' => 'api_settings_walk_score_api_key',
                        'type' => 'text',
                        'title' => esc_html__('Walk Score API Key', 'apushome'),
                        'subtitle' => esc_html__('Add Walk Score API key. To get your Walk Score API key, go to your Walk Score Account.', 'apushome')
                    ),
                )
            );
            
            

            // compare settings
            $realia_fields = array();
            if ( class_exists('Realia_Filter') && is_admin() ) {
                $realia_fields = Realia_Filter::get_fields();
                if ( isset($realia_fields['id']) ) {
                    unset($realia_fields['id']);
                    unset($realia_fields['property_title']);
                }
            }
            $this->sections[] = array(
                'title' => esc_html__('Compare Settings', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'enable_compare_property',
                        'type' => 'switch',
                        'title' => esc_html__('Enable Compare Property', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'property_compare_page_slug',
                        'type' => 'select',
                        'title' => esc_html__('Compare Page', 'apushome'),
                        'options' => $pages,
                        'required' => array('enable_compare_property', '=', 1),
                    ),
                    array(
                        'id'        => 'property_compare_sort_field',
                        'type'      => 'sorter',
                        'title'     => esc_html__( 'Compare Fields', 'apushome' ),
                        'subtitle'  => esc_html__( 'Please drag and arrange the field', 'apushome' ),
                        'options'   => array(
                            'enabled' => $realia_fields,
                            'disabled' => array()
                        ),
                        'required' => array('enable_compare_property', '=', 1)
                    ),
                )
            );
            $this->sections[] = array(
                'title' => esc_html__('Map Settings', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'map_custom_style',
                        'type' => 'textarea',
                        'title' => esc_html__('Map Custom Style', 'apushome'),
                        'description' => wp_kses(__('Add Map Custom Style code. You can find all styles from here <a href="//snazzymaps.com">https://snazzymaps.com</a>', 'apushome'), array('a' => array('href' => array()))),
                    ),
                    array(
                        'id' => 'map_zoom',
                        'type' => 'text',
                        'title' => esc_html__('Map Zoom', 'apushome'),
                        'default' => 15,
                        'min' => '1',
                        'step' => '1',
                        'max' => '20',
                        'type' => 'slider'
                    ),
                    array(
                        'id' => 'map_marker_icon',
                        'type' => 'media',
                        'title' => esc_html__('Map marker Icon', 'apushome'),
                        'subtitle' => esc_html__('Upload a .jpg or .png icon.', 'apushome'),
                    ),
                )
            );
            // submit Property
            $realia_fields = array();
            if ( is_admin() && class_exists('Apushome_Realia_Submition_Form') ) {
                $realia_fields = Apushome_Realia_Submition_Form::default_fields();
            }

            $this->sections[] = array(
                'title' => esc_html__('Submit Property Settings', 'apushome'),
                'fields' => array(
                    array(
                        'id'        => 'property_fields_front',
                        'type'      => 'sorter',
                        'title'     => esc_html__( 'Property Fields', 'apushome' ),
                        'subtitle'  => esc_html__( 'Please drag and arrange the field', 'apushome' ),
                        'options'   => array(
                            'enabled' => $realia_fields,
                            'disabled' => array()
                        ),
                    ),
                )
            );
            // Page IDX settings
            $this->sections[] = array(
                'icon' => 'el el-pencil',
                'title' => esc_html__('Idx Page', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'show_page_idx_breadcrumbs',
                        'type' => 'switch',
                        'title' => esc_html__('Breadcrumbs', 'apushome'),
                        'default' => 1
                    ),
                    array (
                        'title' => esc_html__('Breadcrumbs Background Color', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('The breadcrumbs background color of the site.', 'apushome').'</em>',
                        'id' => 'page_idx_breadcrumb_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array(
                        'id' => 'page_idx_breadcrumb_image',
                        'type' => 'media',
                        'title' => esc_html__('Breadcrumbs Background', 'apushome'),
                        'subtitle' => esc_html__('Upload a .jpg or .png image that will be your breadcrumbs.', 'apushome'),
                    ),
                    array(
                        'id' => 'page_idx_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => esc_html__('Sidebar position', 'apushome'),
                        'subtitle' => esc_html__('Select the variation you want to apply on your store.', 'apushome'),
                        'options' => array(
                            'main' => array(
                                'title' => esc_html__('Main Only', 'apushome'),
                                'alt' => esc_html__('Main Only', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen1.png'
                            ),
                            'left-main' => array(
                                'title' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'alt' => esc_html__('Left - Main Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen2.png'
                            ),
                            'main-right' => array(
                                'title' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'alt' => esc_html__('Main - Right Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen3.png'
                            ),
                            'left-main-right' => array(
                                'title' => esc_html__('Left - Main - Right Sidebar', 'apushome'),
                                'alt' => esc_html__('Left - Main - Right Sidebar', 'apushome'),
                                'img' => get_template_directory_uri() . '/inc/assets/images/screen4.png'
                            ),
                        ),
                        'default' => 'left-main'
                    ),
                    array(
                        'id' => 'page_idx_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Left Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for left sidebar.', 'apushome'),
                        'options' => $sidebars
                    ),
                    array(
                        'id' => 'page_idx_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Archive Right Sidebar', 'apushome'),
                        'subtitle' => esc_html__('Choose a sidebar for right sidebar.', 'apushome'),
                        'options' => $sidebars
                        
                    ),
                )
            );

            // 404 page
            $this->sections[] = array(
                'title' => esc_html__('404 Page', 'apushome'),
                'fields' => array(
                    array(
                        'id' => '404_title',
                        'type' => 'text',
                        'title' => esc_html__('Title', 'apushome'),
                        'default' => '404'
                    ),
                    array(
                        'id' => '404_subtitle',
                        'type' => 'text',
                        'title' => esc_html__('SubTitle', 'apushome'),
                        'default' => 'Opps! Page Not Be Found'
                    ),
                    array(
                        'id' => '404_description',
                        'type' => 'editor',
                        'title' => esc_html__('Description', 'apushome'),
                        'default' => 'Sorry but the page you are looking for does not exist, have been removed, name changed or is temporarity unavailable.'
                    )
                )
            );
            
            // Style
            $this->sections[] = array(
                'icon' => 'el el-icon-css',
                'title' => esc_html__('Style', 'apushome'),
                'fields' => array(
                    array (
                        'id' => 'main_font_info',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Content', 'apushome').'</h3>',
                    ),
                    array (
                        'title' => esc_html__('Main Theme Color', 'apushome'),
                        'subtitle' => esc_html__('The main color of the site.', 'apushome'),
                        'id' => 'main_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Second Theme Color', 'apushome'),
                        'subtitle' => esc_html__('The Second color of the site.', 'apushome'),
                        'id' => 'second_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Button Main Theme Color', 'apushome'),
                        'subtitle' => esc_html__('The main color of the site.', 'apushome'),
                        'id' => 'button_main_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Button Main Hover Theme Color', 'apushome'),
                        'subtitle' => esc_html__('The main color of the site.', 'apushome'),
                        'id' => 'button_hover_main_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Button Second Theme Color', 'apushome'),
                        'subtitle' => esc_html__('The Second color of the site.', 'apushome'),
                        'id' => 'button_second_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),
                    array (
                        'title' => esc_html__('Button Second Hover Theme Color', 'apushome'),
                        'subtitle' => esc_html__('The Second color of the site.', 'apushome'),
                        'id' => 'button_hover_second_color',
                        'type' => 'color',
                        'transparent' => false,
                    ),

                    array (
                        'id' => 'site_background',
                        'type' => 'background',
                        'title' => esc_html__('Site Background', 'apushome'),
                        'output' => 'body'
                    ),
                    array (
                        'id' => 'forms_inputs_bg',
                        'type' => 'color_rgba',
                        'title' => esc_html__('Forms inputs Color', 'apushome'),
                        'output' => array(
                            'background-color' =>'.form-control, select, input[type="text"], input[type="email"], input[type="password"], input[type="tel"], textarea, textarea.form-control'
                        )
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Typography', 'apushome'),
                'fields' => array(
                    
                    array (
                        'id' => 'main_font_info',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Body Font', 'apushome').'</h3>',
                    ),
                    // Standard + Google Webfonts
                    array (
                        'title' => esc_html__('Font Face', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('Pick the Main Font for your site.', 'apushome').'</em>',
                        'id' => 'main_font',
                        'type' => 'typography',
                        'line-height' => true,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => true,
                        'all_styles'=> true,
                        'font-size' => true,
                        'color' => true
                    ),
                    array (
                        'title' => esc_html__('Font Face Second', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('Pick the Second Font for your site( Heading).', 'apushome').'</em>',
                        'id' => 'second_font',
                        'type' => 'typography',
                        'line-height' => true,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => true,
                        'all_styles'=> true,
                        'font-size' => true,
                        'color' => true
                    ),
                    
                    // Header
                    array (
                        'id' => 'secondary_font_info',
                        'icon' => true,
                        'type' => 'info',
                        'raw' => '<h3 style="margin: 0;"> '.esc_html__('Heading', 'apushome').'</h3>',
                    ),
                    array (
                        'title' => esc_html__('H1 Font', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('Pick the H1 Font for your site.', 'apushome').'</em>',
                        'id' => 'h1_font',
                        'type' => 'typography',
                        'line-height' => true,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => true,
                        'all_styles'=> true,
                        'font-size' => true,
                        'color' => true,
                        'output' => 'h1'
                    ),
                    array (
                        'title' => esc_html__('H2 Font', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('Pick the H2 Font for your site.', 'apushome').'</em>',
                        'id' => 'h2_font',
                        'type' => 'typography',
                        'line-height' => true,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => true,
                        'all_styles'=> true,
                        'font-size' => true,
                        'color' => true,
                        'output' => 'h2, .apus-breadscrumb .bread-title'
                    ),
                    array (
                        'title' => esc_html__('H3 Font', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('Pick the H3 Font for your site.', 'apushome').'</em>',
                        'id' => 'h3_font',
                        'type' => 'typography',
                        'line-height' => true,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => true,
                        'all_styles'=> true,
                        'font-size' => true,
                        'color' => true,
                        'output' => 'h3, .widgettitle, .widget-title, .search2_properties .widget-title, .widget .widgettitle'
                    ),
                    array (
                        'title' => esc_html__('H4 Font', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('Pick the H4 Font for your site.', 'apushome').'</em>',
                        'id' => 'h4_font',
                        'type' => 'typography',
                        'line-height' => true,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => true,
                        'all_styles'=> true,
                        'font-size' => true,
                        'color' => true,
                        'output' => 'h4'
                    ),
                    array (
                        'title' => esc_html__('H5 Font', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('Pick the H5 Font for your site.', 'apushome').'</em>',
                        'id' => 'h5_font',
                        'type' => 'typography',
                        'line-height' => true,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => true,
                        'all_styles'=> true,
                        'font-size' => true,
                        'color' => true,
                        'output' => 'h5'
                    ),
                    array (
                        'title' => esc_html__('H6 Font', 'apushome'),
                        'subtitle' => '<em>'.esc_html__('Pick the H6 Font for your site.', 'apushome').'</em>',
                        'id' => 'h6_font',
                        'type' => 'typography',
                        'line-height' => true,
                        'text-align' => false,
                        'font-style' => false,
                        'font-weight' => true,
                        'all_styles'=> true,
                        'font-size' => true,
                        'color' => true,
                        'output' => 'h6'
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Top Bar', 'apushome'),
                'fields' => array(
                    array(
                        'id'=>'topbar_bg',
                        'type' => 'background',
                        'title' => esc_html__('Background', 'apushome'),
                        'output' => '.apus-topbar'
                    ),
                    array(
                        'title' => esc_html__('Text Color', 'apushome'),
                        'id' => 'topbar_text_color',
                        'type' => 'color_rgba',
                        'output' => array(
                            'color' =>'.apus-topbar'
                        )
                    ),
                    array(
                        'title' => esc_html__('Link Color', 'apushome'),
                        'id' => 'topbar_link_color',
                        'type' => 'color_rgba',
                        'output' => array(
                            'color' =>'.apus-topbar a'
                        )
                    ),
                    array(
                        'title' => esc_html__('Link Color When Hover', 'apushome'),
                        'id' => 'topbar_link_color_hover',
                        'type' => 'color_rgba',
                        'output' => array(
                            'color' =>'.apus-topbar a:hover,.apus-topbar a:active'
                        )
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Header', 'apushome'),
                'fields' => array(
                    array(
                        'id'=>'header_bg',
                        'type' => 'background',
                        'title' => esc_html__('Background', 'apushome'),
                        'output' => '#apus-header,.sticky-header .header-middle,.header-v1 .sticky-header .header-middle'
                    ),
                    array(
                        'title' => esc_html__('Text Color', 'apushome'),
                        'id' => 'header_text_color',
                        'type' => 'color',
                        'output' => array(
                            'color' =>'#apus-header'
                        )
                    ),
                    array(
                        'title' => esc_html__('Link Color', 'apushome'),
                        'id' => 'header_link_color',
                        'type' => 'color',
                        'output' => array(
                            'color' =>'#apus-header a'
                        )
                    ),
                    array(
                        'title' => esc_html__('Link Color Active', 'apushome'),
                        'id' => 'header_link_color_active',
                        'type' => 'color',
                        'output' => array(
                            'color' =>'#apus-header .active > a, #apus-header a:active, #apus-header a:hover'
                        )
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Main Menu', 'apushome'),
                'fields' => array(
                    array(
                        'title' => esc_html__('Link Color', 'apushome'),
                        'id' => 'main_menu_link_color',
                        'type' => 'color',
                        'output' => array(
                            'color' =>'#apus-header .navbar-nav.megamenu > li > a'
                        )
                    ),
                    array(
                        'title' => esc_html__('Link Color Active', 'apushome'),
                        'id' => 'main_menu_link_color_active',
                        'type' => 'color',
                        'output' => array(
                            'color' =>'.navbar-nav.megamenu .dropdown-menu > li > a:hover, .navbar-nav.megamenu .dropdown-menu > li > a:active,.navbar-nav.megamenu .dropdown-menu > li.open > a, .navbar-nav.megamenu .dropdown-menu > li.active > a,#apus-header .navbar-nav.megamenu > li.active > a,#apus-header .navbar-nav.megamenu > li:hover > a,#apus-header .navbar-nav.megamenu > li:active > a'
                        )
                    ),
                )
            );
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Footer', 'apushome'),
                'fields' => array(
                    array(
                        'id'=>'footer_bg',
                        'type' => 'background',
                        'title' => esc_html__('Background', 'apushome'),
                        'output' => '.apus-footer'
                    ),
                    array(
                        'title' => esc_html__('Heading Color', 'apushome'),
                        'id' => 'footer_heading_color',
                        'type' => 'color',
                        'output' => array(
                            'color' => '#apus-footer .widgettitle ,#apus-footer .widget-title'
                        )
                    ),
                    array(
                        'title' => esc_html__('Text Color', 'apushome'),
                        'id' => 'footer_text_color',
                        'type' => 'color',
                        'output' => array(
                            'color' => '#apus-footer, .apus-footer .contact-info, .apus-copyright'
                        )
                    ),
                    array(
                        'title' => esc_html__('Link Color', 'apushome'),
                        'id' => 'footer_link_color',
                        'type' => 'color',
                        'output' => array(
                            'color' => '#apus-footer a'
                        )
                    ),
                    array(
                        'title' => esc_html__('Link Color Hover', 'apushome'),
                        'id' => 'footer_link_color_hover',
                        'type' => 'color',
                        'output' => array(
                            'color' => '#apus-footer a:hover'
                        )
                    ),
                )
            );
            
            $this->sections[] = array(
                'subsection' => true,
                'title' => esc_html__('Copyright', 'apushome'),
                'fields' => array(
                    array(
                        'id'=>'copyright_bg',
                        'type' => 'background',
                        'title' => esc_html__('Background', 'apushome'),
                        'output' => '.apus-copyright'
                    ),
                    array(
                        'title' => esc_html__('Text Color', 'apushome'),
                        'id' => 'copyright_text_color',
                        'type' => 'color',
                        'output' => array(
                            'color' => '.apus-copyright'
                        )
                    ),
                    array(
                        'title' => esc_html__('Link Color', 'apushome'),
                        'id' => 'copyright_link_color',
                        'type' => 'color',
                        'output' => array(
                            'color' => '.apus-copyright a, .apus-copyright a i'
                        )
                    ),
                    array(
                        'title' => esc_html__('Link Color Hover', 'apushome'),
                        'id' => 'copyright_link_color_hover',
                        'type' => 'color',
                        'output' => array(
                            'color' => '.apus-copyright a:hover .apus-copyright a i:hover'
                        )
                    ),
                )
            );

            // Social Media
            $this->sections[] = array(
                'icon' => 'el el-file',
                'title' => esc_html__('Social Media', 'apushome'),
                'fields' => array(
                    array(
                        'id' => 'facebook_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable Facebook Share', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'twitter_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable twitter Share', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'linkedin_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable linkedin Share', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'tumblr_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable tumblr Share', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'google_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable google plus Share', 'apushome'),
                        'default' => 1
                    ),
                    array(
                        'id' => 'pinterest_share',
                        'type' => 'switch',
                        'title' => esc_html__('Enable pinterest Share', 'apushome'),
                        'default' => 1
                    )
                )
            );
            // Custom Code
            $this->sections[] = array(
                'icon' => 'el-icon-css',
                'title' => esc_html__('Custom CSS/JS', 'apushome'),
                'fields' => array(
                    array (
                        'title' => esc_html__('Custom CSS', 'apushome'),
                        'subtitle' => esc_html__('Paste your custom CSS code here.', 'apushome'),
                        'id' => 'custom_css',
                        'type' => 'ace_editor',
                        'mode' => 'css',
                    ),
                    array (
                        'title' => esc_html__('Custom JavaScript Code', 'apushome'),
                        'subtitle' => esc_html__('Here is the place to paste your Google Analytics code or any other JS code you might want to add to be loaded in the footer of your website.', 'apushome'),
                        'id' => 'custom_js',
                        'type' => 'ace_editor',
                        'mode' => 'javascript',
                    ),
                )
            );
            $this->sections[] = array(
                'title' => esc_html__('Import / Export', 'apushome'),
                'desc' => esc_html__('Import and Export your Redux Framework settings from file, text or URL.', 'apushome'),
                'icon' => 'el-icon-refresh',
                'fields' => array(
                    array(
                        'id' => 'opt-import-export',
                        'type' => 'import_export',
                        'title' => 'Import Export',
                        'subtitle' => 'Save and restore your Redux options',
                        'full_width' => false,
                    ),
                ),
            );

            $this->sections[] = array(
                'type' => 'divide',
            );


        }
        /**
         * All the possible arguments for Redux.
         * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
         * */
        public function setArguments()
        {
            $theme = wp_get_theme(); // For use with some settings. Not necessary.
            
            $preset = apushome_get_demo_preset();
            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name' => 'apushome_theme_options'.$preset,
                // This is where your data is stored in the database and also becomes your global variable name.
                'display_name' => $theme->get('Name'),
                // Name that appears at the top of your panel
                'display_version' => $theme->get('Version'),
                // Version that appears at the top of your panel
                'menu_type' => 'menu',
                //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu' => true,
                // Show the sections below the admin menu item or not
                'menu_title' => esc_html__('Theme Options', 'apushome'),
                'page_title' => esc_html__('Theme Options', 'apushome'),

                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key' => '',
                // Set it you want google fonts to update weekly. A google_api_key value is required.
                'google_update_weekly' => false,
                // Must be defined to add google fonts to the typography module
                'async_typography' => true,
                // Use a asynchronous font on the front end or font string
                //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
                'admin_bar' => true,
                // Show the panel pages on the admin bar
                'admin_bar_icon' => 'dashicons-portfolio',
                // Choose an icon for the admin bar menu
                'admin_bar_priority' => 50,
                // Choose an priority for the admin bar menu
                'global_variable' => 'apus_options',
                // Set a different name for your global variable other than the opt_name
                'dev_mode' => false,
                // Show the time the page took to load, etc
                'update_notice' => true,
                // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
                'customizer' => true,
                // Enable basic customizer support
                //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
                //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

                // OPTIONAL -> Give you extra features
                'page_priority' => null,
                // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent' => 'themes.php',
                // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions' => 'manage_options',
                // Permissions needed to access the options panel.
                'menu_icon' => '',
                // Specify a custom URL to an icon
                'last_tab' => '',
                // Force your panel to always open to a specific tab (by id)
                'page_icon' => 'icon-themes',
                // Icon displayed in the admin panel next to your menu_title
                'page_slug' => '_options',
                // Page slug used to denote the panel
                'save_defaults' => true,
                // On load save the defaults to DB before user clicks save or not
                'default_show' => false,
                // If true, shows the default value next to each field that is not the default value.
                'default_mark' => '',
                // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export' => true,
                // Shows the Import/Export panel when not used as a field.

                // CAREFUL -> These options are for advanced use only
                'transient_time' => 60 * MINUTE_IN_SECONDS,
                'output' => true,
                // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag' => true,
                // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database' => '',
                // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'system_info' => false,
                // REMOVE
                'use_cdn' => true
            );

            $this->args['intro_text'] = '';

            // Add content after the form.
            $this->args['footer_text'] = '';
            return $this->args;
        }

    }

    global $reduxConfig;
    $reduxConfig = new Apushome_Redux_Framework_Config();
}

if ( function_exists('apus_framework_redux_register_custom_extension_loader') ) {
    $preset = apushome_get_demo_preset();
    $opt_name = 'apushome_theme_options'.$preset;
    add_action("redux/extensions/{$opt_name}/before", 'apus_framework_redux_register_custom_extension_loader', 0);
}