<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
?>

<?php $property = isset( $property ) ? $property : get_post(); ?>

<?php
    $is_sticky = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'sticky', true );
    $status = Realia_Query::get_property_status_name();
    
    $latitude = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'map_location_latitude', true );
    $longitude = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'map_location_longitude', true );

    $content = str_replace( array( "\r\n", "\n", "\t" ), '', Realia_Template_Loader::load( 'misc/google-map-infowindow' ) );
    $marker_content = str_replace( array( "\r\n", "\n", "\t" ), '', Realia_Template_Loader::load( 'misc/google-map-marker' ) );
?>
<div class="property-box property-box-wrapper property-box-grid-style1" data-latitude="<?php echo esc_attr($latitude); ?>" data-longitude="<?php echo esc_attr($longitude); ?>" data-markerid="marker-<?php echo esc_attr($property->ID); ?>">
    <div class="property-map-content-wrapper hidden">
        <div class="property-map-content">
            <?php echo trim($content); ?>
        </div>
        <div class="property-map-marker">
            <?php echo trim($marker_content); ?>
        </div>
    </div>
    <div class="property-box-top clearfix">
        <?php $price = Realia_Price::get_property_price( $property->ID ); ?>
        <?php if ( ! empty( $price ) ) : ?>
            <div class="property-box-price text-theme">
                <?php echo wp_kses( $price, wp_kses_allowed_html( 'post' ) ); ?>
            </div><!-- /.property-box-price -->
        <?php endif; ?>

        <?php
        if ( class_exists('Apushome_Realia_Compare') ) {
            Apushome_Realia_Compare::display_compare_btn( $property->ID );
        }
        ?>
        <!-- share -->
        <div class="property-box-share pull-right">
            <a href="#share-box" data-toggle="tooltip" data-placement="top" title="<?php echo esc_html__( 'Share', 'apushome' ); ?>">
                <i class="icon-ap_share"></i>
            </a>
            <div class="property-box-share-content">
                <?php get_template_part( 'page-templates/parts/sharebox-property' ); ?>
            </div>
        </div>

        <?php if ( class_exists('Apushome_Realia_Favorite') ) { ?>
            <div class="pull-right">
                <?php Apushome_Realia_Favorite::btn_display( $property->ID ); ?>
            </div>
        <?php } ?>
    </div>
    <div class="property-box-image <?php if ( ! has_post_thumbnail( $property ) ) { echo 'without-image'; } ?>">
        <a href="<?php the_permalink(); ?>" class="property-box-image-inner">
            <?php
            /**
             * realia_before_property_box_image
             */
            do_action( 'realia_before_property_box_image', $property->ID );
            ?>
            <?php //the_post_thumbnail( 'medium' ); ?>

            <?php apushome_realia_post_thumbnail($property, 'apushome-standard-size'); ?>
            
            <div class="meta-top">
                <?php
                /**
                 * realia_after_property_box_image
                 */
                do_action( 'realia_after_property_box_image', $property->ID );
                ?>
                
                <?php apushome_realia_contract_label( $property->ID ); ?>

                <?php $is_featured = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'featured', true ); ?>
                <?php $is_reduced = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'reduced', true ); ?>

                <?php if ( $is_featured && $is_reduced ) : ?>
                    <span class="property-badge reduced"><?php echo esc_html__( 'Featured', 'apushome' ); ?> / <?php echo esc_html__( 'Reduced', 'apushome' ); ?></span>
                <?php elseif ( $is_reduced ) : ?>
                    <span class="property-badge"><?php echo esc_html__( 'Reduced', 'apushome' ); ?></span>
                <?php endif; ?>
                <?php if ( $is_sticky ) : ?>
                    <span class="property-badge property-badge-sticky"><?php echo esc_html__( 'TOP', 'apushome' ); ?></span>
                <?php endif; ?>
                
            </div>
            <?php if ( $is_featured ) : ?>
                <div class="property-badge feature"><?php echo esc_html__( 'Featured', 'apushome' ); ?></div>
            <?php endif; ?>
        </a>

        <div class="property-box-content">
            <?php
                $video = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'video', true );
                $gallery = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'gallery', true )
            ?>
            <?php if ( !empty( $video ) || !empty($gallery) ) { ?>
                <div class="meta-bottom">
                    <?php if ( !empty( $video ) ) { ?>
                        <span><i class="icon-ap_video"></i></span>
                    <?php } ?>
                    <?php if ( !empty( $gallery ) ) { ?>
                        <span><i class="icon-ap_pic"></i> <?php echo trim(count($gallery)); ?></span>
                    <?php } ?>
                </div>
            <?php } ?>
            <div class="property-box-title-wrap">
                <div class="property-box-title">
                    <h3 class="entry-title"><a href="<?php the_permalink( $property ); ?>"><?php echo get_the_title( $property ) ?></a></h3>
                    <?php $location = Realia_Query::get_property_location_name( null, ',' ); ?>
                    <?php if ( ! empty( $location ) ) : ?>
                        <div class="property-row-location">
                            <i class="icon-ap_pin" aria-hidden="true"></i>
                            <?php echo wp_kses( $location, wp_kses_allowed_html( 'post' ) ); ?>
                        </div>
                    <?php endif; ?>
                </div>
                
            </div><!-- /.property-box-title -->
            <div class="property-box-meta clearfix">
                <?php $home_area = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'home_area', true ); ?>
                <?php if ( ! empty( $home_area ) ) : ?>
                    <div class="field-item">
                        <i class="icon-ap_area"></i>
                        <?php echo sprintf(__('<span>%s</span>', 'apushome'), $home_area.' '.get_theme_mod( 'realia_measurement_area_unit', null ) ); ?>
                    </div>
                <?php endif; ?>

                <?php $beds = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'beds', true ); ?>
                <?php if ( ! empty( $beds ) ) : ?>
                    <div class="field-item">
                        <i class="icon-ap_bed-room"></i>
                        <?php echo sprintf(_n('<span>%s</span>', '<span>%s</span>', $beds, 'apushome'), $beds); ?>
                    </div>
                <?php endif; ?>

                <?php $baths = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'baths', true ); ?>
                <?php if ( ! empty( $baths ) ) : ?>
                    <div class="field-item">
                        <i class="icon-ap_bath-room"></i>
                        <?php echo sprintf(_n('<span>%s</span>', '<span>%s</span>', $baths, 'apushome'), $baths); ?>
                    </div>
                <?php endif; ?>

                <?php $garages = get_post_meta( $property->ID, REALIA_PROPERTY_PREFIX . 'garages', true ); ?>
                <?php if ( ! empty( $garages ) ) : ?>
                    <div class="field-item last-childen">
                        <i class="icon-ap_car-park"></i>
                        <?php echo sprintf(_n('<span>%s</span>', '<span>%s</span>', $garages, 'apushome'), $garages); ?>
                    </div>
                <?php endif; ?>
            </div>

        </div><!-- /.property-box-content -->
    </div><!-- /.property-image -->

</div>